if [ -x /usr/bin/update-desktop-database ]; then
  /usr/bin/update-desktop-database -q usr/share/applications 1>/dev/null 2> /dev/null
fi

if [ -e usr/share/icons/hicolor/icon-theme.cache ]; then
  if [ -x /usr/bin/gtk-update-icon-cache ]; then
    /usr/bin/gtk-update-icon-cache usr/share/icons/hicolor 1>/dev/null 2> /dev/null
  fi
fi

if [ -e usr/share/glib-2.0/schemas ]; then
  if [ -x /usr/bin/glib-compile-schemas ]; then
    /usr/bin/glib-compile-schemas usr/share/glib-2.0/schemas >/dev/null 2>&1
  fi
fi

( cd usr/lib ; rm -rf libnm-gtk.so )
( cd usr/lib ; ln -sf libnm-gtk.so.0.0.0 libnm-gtk.so )
( cd usr/lib ; rm -rf libnm-gtk.so.0 )
( cd usr/lib ; ln -sf libnm-gtk.so.0.0.0 libnm-gtk.so.0 )
